import { env } from '$env/dynamic/private'
import { Bot, type Post } from "@skyware/bot";
import { get, writable } from 'svelte/store'

const bskyClient = writable<null | Bot>(null)

export const getBskyClient = async () => {
    let client = get(bskyClient)
    if (client === null) {
        client = await loginToBsky()
        bskyClient.set(client)
    }
    return client
}

const loginToBsky = async () => {
    const bot = new Bot({ service: "https://gaze.systems" })
    await bot.login({ identifier: 'guestbook.gaze.systems', password: env.BSKY_PASSWORD ?? "" })
    return bot
}

export const getUserPosts = async (did: string, count: number = 10, cursor: string | null = null) => {
    const client = await getBskyClient()
    let feedCursor: string | null | undefined = cursor;
    let posts: Post[] = []
    // fetch requested amount of posts
    while (posts.length < count - 1 && (typeof feedCursor === "string" || feedCursor === null)) {
        let feedData = await client.getUserPosts(
            did, { limit: count, filter: 'posts_no_replies', cursor: feedCursor === null ? undefined : feedCursor }
        )
        posts.push(...feedData.posts.filter((post) => post.author.did === did))
        feedCursor = feedData.cursor
    }
    return { posts, cursor: feedCursor === null ? undefined : feedCursor }
}

const lastPosts = writable<Post[]>([])

export const updateLastPosts = async () => {
    const { posts } = await getUserPosts("did:plc:dfl62fgb7wtjj3fcbb72naae", 13)
    lastPosts.set(posts)
}

export const getLastPosts = () => { return get(lastPosts) }